Package: lemon
Type: Package
Title: Freshing Up your 'ggplot2' Plots
URL: https://github.com/stefanedwards/lemon
BugReports: https://github.com/stefanedwards/lemon/issues
Version: 0.3.3
Date: 2018-01-31
Authors@R: c(
    person('Stefan McKinnon', 'Edwards', email='sme@iysik.com',
    comment=c(ORCID='0000-0002-4628-8148'),
    role=c('aut','ctb','cre')),
    person('Baptiste','Auguie', role='ctb',
    comment='For g_legend and grid_arrange_shared_legend'),
    person('Shaun','Jackman', role='ctb',
    comment='For grid_arrange_shared_legend'),
    person("Hadley", "Wickham", , "hadley@rstudio.com", "ctb",
    comment='ggplot2 functions'),
    person("Winston", "Chang", , "winston@rstudio.com", "ctb",
    comment='ggplot2 functions')
    )
Description: Functions for working with legends and axis lines of 'ggplot2',
    facets that repeat axis lines on all panels, and some 'knitr' extensions.
Depends: R (>= 3.1.0)
Imports: ggplot2 (>= 2.2.0), grid, gridExtra, gtable, knitr (>= 1.12),
        lattice
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1
Collate: 'ggplot2.r' 'brackets.R' 'coord-flex.r' 'coord-capped.r'
        'dot.r' 'facet-rep-lab.r' 'facet-wrap.r' 'geom-pointline.r'
        'gtable_show-.r' 'guides-axis.r' 'legends.r' 'lemon.r'
        'lemon_print.r'
Suggests: rmarkdown, stringr, dplyr, tidyverse, testthat
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2018-01-31 11:48:36 UTC; shojedw
Author: Stefan McKinnon Edwards [aut, ctb, cre]
    (<https://orcid.org/0000-0002-4628-8148>),
  Baptiste Auguie [ctb] (For g_legend and grid_arrange_shared_legend),
  Shaun Jackman [ctb] (For grid_arrange_shared_legend),
  Hadley Wickham [ctb] (ggplot2 functions),
  Winston Chang [ctb] (ggplot2 functions)
Maintainer: Stefan McKinnon Edwards <sme@iysik.com>
Repository: CRAN
Date/Publication: 2018-01-31 12:43:54 UTC
Built: R 3.4.1; ; 2018-03-01 00:36:32 UTC; windows
