# Generated by roxygen2: do not edit by hand

S3method(lemon_print,data.frame)
S3method(lemon_print,table)
export(.dot)
export(.dot2)
export(CoordFlexCartesian)
export(CoordFlexFixed)
export(CoordFlexFlipped)
export(FacetGridRepeatLabels)
export(FacetWrapRepeatLabels)
export(GeomPointLine)
export(GeomPointPath)
export(brackets_horisontal)
export(brackets_horizontal)
export(brackets_vertical)
export(capped_horisontal)
export(capped_horizontal)
export(capped_vertical)
export(coord_capped_cart)
export(coord_capped_flip)
export(coord_flex_cart)
export(coord_flex_fixed)
export(coord_flex_flip)
export(facet_rep_grid)
export(facet_rep_wrap)
export(g_legend)
export(geom_pointline)
export(geom_pointpath)
export(grid_arrange_shared_legend)
export(gtable_show_grill)
export(gtable_show_names)
export(lemon_print)
export(reposition_legend)
import(ggplot2)
import(grDevices)
import(grid)
import(gridExtra)
import(gtable)
import(knitr)
import(lattice)
